@@ -43,7 +43,7 @@ void PGFExporterImpVisitor::newLine()
 QString PGFExporterImpVisitor::emitPenColor( const QColor& c )
 {
   QString pencolor("");
-  pencolor = "color={rgb,255:red," + QString::number(c.red()) + ";green," + QString::number(c.green()) + ";blue," + QString::number(c.blue()) + "}";
+  pencolor = "color={rgb,255:red," + QString::number(c.red()) + ";green," + QString::number(c.green()) + ";blue," + QString::number(c.blue()) + '}';
   return pencolor;
 }
 
@@ -112,7 +112,7 @@ QString PGFExporterImpVisitor::emitStyle( const ObjectDrawer* od )
 QString PGFExporterImpVisitor::emitCoord( const Coordinate& c )
 {
   QString ret("");
-  ret = "(" + QString::number(c.x) + "," + QString::number(c.y) + ")";
+  ret = '(' + QString::number(c.x) + ',' + QString::number(c.y) + ')';
   return ret;
 }
 
