@@ -27,7 +27,7 @@
 #include "../../modes/normal.h"
 #include "../../objects/text_type.h"
 
-#include <KIconLoader>
+#include <KIconEngine>
 
 /**
  * this is a local function that looks for a python script associated
@@ -61,7 +61,7 @@ void ScriptActionsProvider::fillUpMenu( NormalModePopupObjects& popup, int menu,
   if ( menu == NormalModePopupObjects::StartMenu )
   {
     KIconLoader* l = popup.part().iconLoader();
-    popup.addInternalAction( menu, KIcon( ScriptType::icon( ScriptType::Python ), l ), i18n( "Python Script" ), nextfree++ );
+    popup.addInternalAction( menu, QIcon( new KIconEngine( ScriptType::icon( ScriptType::Python ), l ) ), i18n( "Python Script" ), nextfree++ );
     mns++;
   }
   else if ( menu == NormalModePopupObjects::ToplevelMenu )
